package ch.zhaw.gartenverwaltung.io;

import ch.zhaw.gartenverwaltung.types.Crop;
import ch.zhaw.gartenverwaltung.types.Task;

import java.io.IOException;
import java.time.LocalDate;
import java.util.List;

public class WeatherGradenTaskPlanner {
    private final TaskList taskList;
    WeatherService weatherService;
    private final LocalDate dateSevereWeather = LocalDate.of(22,12,15);

    public WeatherGradenTaskPlanner(TaskList taskList) {
        this.taskList = taskList;
        weatherService = new WeatherService();
    }

    public void getWeatherEvents() throws IOException {
        Enum actualWeather = weatherService.causeSevereWeather(0);
        if (SevereWeather.HAIL.equals(actualWeather)) {
            createPreHail();
        } else if (SevereWeather.FROST.equals(actualWeather)) {
            createPreFrost();
        } else if (SevereWeather.SNOW.equals(actualWeather)) {
            createPreSnow();
        }
    }

    public void createPreHail() throws IOException {

        Task preHailTask = new Task("Hail",
                                    "During a summer Thunderstorm it could hail heavily. THe Hail could damage the crops. To prevent damage cover the plants with a strong tarpaulin",
                                    dateSevereWeather.minusDays(1L));
        preHailTask.withId(Long.MAX_VALUE);
        taskList.saveTask(preHailTask);

    }

    public void createPreFrost() throws IOException {
        Task preFrostTask = new Task("Frost",
                                    "The temperatur falls below zero degrees, cover especially the root with wool",
                                    dateSevereWeather.minusDays(1L));
        preFrostTask.withId(Long.MAX_VALUE);
        taskList.saveTask(preFrostTask);
    }

    public void createPreSnow() throws IOException {
        Task preSnowTask = new Task("Snow",
                                    "The weather brings little snowfall. Cover your crops",
                                    dateSevereWeather.minusDays(1L));
        preSnowTask.withId(Long.MAX_VALUE);
        taskList.saveTask(preSnowTask);
    }

    public void calculateRainAmount(){

    }

    public void adjustWateringTask(List<Crop> crops){

    }
}
